@@ -9,12 +9,13 @@ def getTree(URL):
     headers = {
         'user-agent': 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_11_6) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/53.0.2785.143 Safari/537.36',
         'Accept-Language': 'en-gb',
-        'Accept-Encoding': 'br, gzip, deflate',
+        # 'Accept-Encoding': 'br, gzip, deflate',
         'Accept': 'test/html,application/xhtml+xml,application/xml;q=0.9,*/*;q=0.8',
     }
     try:
         r = requests.get(URL, headers=headers, timeout=10)
-        tree = html.fromstring(r.content.decode("utf-8", "replace"))
+        # tree = html.fromstring(r.content.decode("utf-8", "replace"))
+        tree = html.fromstring(r.content)
         return tree
     except Exception as e:
         print(e)
